@@ -1,4 +1,3 @@
-
 # knitr-related functions --------------------------------------------------------------------------
 
 
@@ -10,50 +9,55 @@
 #'
 #' @details
 #' knitr calls [knitr::knit_print()] on objects when they are printed in a knitr (or RMarkdown) document.
-#' The method for `huxtable` objects guesses the appropriate output format and
+#' The method for `huxtable` objects guesses the appropriate output format
+#' (including Typst documents when using the `typst` package) and
 #' prints itself out appropriately. You can override the output format by setting
 #' `options("huxtable.knitr_output_format")`.
 #'
 #' @family knit_print
 #' @seealso [huxtable-options]
-knit_print.huxtable <- function (x, options, ...) {
+knit_print.huxtable <- function(x, options, ...) {
   # guess... runs assert_package for knitr
   of <- getOption("huxtable.knitr_output_format", guess_knitr_output_format())
   call_name <- switch(of,
-        latex  = "to_latex",
-        html   = "to_html",
-        pptx   = ,
-        docx   = "as_flextable",
-        md     = "to_md",
-        screen = "to_screen",
-        rtf    = "to_rtf",
-        { # default
-        warning(glue::glue(
-            'Unrecognized output format "{of}". Using `to_screen` to print huxtables.\n',
-            'Set options("huxtable.knitr_output_format") manually to ',
-            '"latex", "html", "rtf", "docx", "pptx", "md" or "screen".'))
-          "to_screen"
-        })
+    latex = "to_latex",
+    html = "to_html",
+    pptx = ,
+    docx = "as_flextable",
+    md = "to_md",
+    screen = "to_screen",
+    rtf = "to_rtf",
+    typst = "to_typst",
+    { # default
+      warning(glue::glue(
+        'Unrecognized output format "{of}". Using `to_screen` to print huxtables.\n',
+        'Set options("huxtable.knitr_output_format") manually to ',
+        '"latex", "html", "rtf", "docx", "pptx", "md", "typst" or "screen".'
+      ))
+      "to_screen"
+    }
+  )
 
   res <- do.call(call_name, list(x))
 
   res <- switch(of,
-            latex = {
-              latex_deps <- report_latex_dependencies(quiet = TRUE)
-              tenv <- tabular_environment(x)
-              if (tenv %in% c("tabulary", "longtable")) {
-                latex_deps <- c(latex_deps, list(rmarkdown::latex_dependency(tenv)))
-              }
-              knitr::asis_output(res, meta = latex_deps)
-            },
-            html = knitr::asis_output(
-                     htmltools::htmlPreserve(res)
-                   ),
-            rtf  = knitr::raw_output(res),
-            pptx = ,
-            docx = knitr::knit_print(res),
-            knitr::asis_output(res)
-          )
+    latex = {
+      latex_deps <- report_latex_dependencies(quiet = TRUE)
+      tenv <- tabular_environment(x)
+      if (tenv %in% c("tabulary", "longtable")) {
+        latex_deps <- c(latex_deps, list(rmarkdown::latex_dependency(tenv)))
+      }
+      knitr::asis_output(res, meta = latex_deps)
+    },
+    html = knitr::asis_output(
+      htmltools::htmlPreserve(res)
+    ),
+    rtf = knitr::raw_output(res),
+    pptx = ,
+    docx = knitr::knit_print(res),
+    typst = knitr::asis_output(res),
+    knitr::asis_output(res)
+  )
 
   return(res)
 }
@@ -76,27 +80,32 @@ knit_print.huxtable <- function (x, options, ...) {
 #' @examples
 #' \dontrun{
 #' # in your knitr document
-#' mytheme <- function (ht) {
+#' mytheme <- function(ht) {
 #'   ht <- set_all_borders(ht, 0.4)
-#'   ht <- set_all_border_colors(ht,
-#'         "darkgreen")
-#'   ht <- set_background_color(ht,
-#'         evens, odds, "salmon")
+#'   ht <- set_all_border_colors(
+#'     ht,
+#'     "darkgreen"
+#'   )
+#'   ht <- set_background_color(
+#'     ht,
+#'     evens, odds, "salmon"
+#'   )
 #'   ht
 #' }
 #'
-#' options(huxtable.knit_print_df_theme
-#'       = mytheme)
+#' options(
+#'   huxtable.knit_print_df_theme = mytheme
+#' )
 #' # groovy!
 #' data.frame(
-#'         a = 1:5,
-#'         b = 1:5
-#'       )
+#'   a = 1:5,
+#'   b = 1:5
+#' )
 #' }
 knit_print.data.frame <- function(x, options, ...) {
   # the FALSE default is so that this does not get called unless
   # huxtable has been explicitly attached
-  if (! isTRUE(getOption("huxtable.knit_print_df", FALSE))) {
+  if (!isTRUE(getOption("huxtable.knit_print_df", FALSE))) {
     NextMethod() # probably calls knit_print.default
   } else {
     ht <- as_huxtable(x)
@@ -113,8 +122,8 @@ knit_print.data.frame <- function(x, options, ...) {
 #'
 #' Convenience function which tries to guess the ultimate output from knitr and rmarkdown.
 #'
-#' @return "html", "latex", or something else. If we are not in a knitr document, returns an empty
-#'   string.
+#' @return "html", "latex", "typst", or something else. If we are not in a knitr document,
+#'   returns an empty string.
 #' @export
 #'
 #' @examples
@@ -131,7 +140,9 @@ guess_knitr_output_format <- function() {
     of <- knitr::opts_knit$get("rmarkdown.pandoc.to")
     if (is.null(of)) {
       knit_in <- knitr::current_input()
-      if (is.null(knit_in)) return("")
+      if (is.null(knit_in)) {
+        return("")
+      }
       of <- rmarkdown::default_output_format(knit_in)
       of <- of$name
     }
@@ -139,6 +150,7 @@ guess_knitr_output_format <- function() {
   if (of == "tufte_handout") of <- "latex"
   if (of == "tufte_html") of <- "html"
   of <- sub("_.*", "", of)
+  if (grepl("typst", of, ignore.case = TRUE)) of <- "typst"
   if (of == "html4") of <- "html" # bookdown
   if (of %in% c("ioslides", "revealjs", "slidy")) of <- "html"
   if (of %in% c("beamer", "pdf")) of <- "latex"
