@@ -1,4 +1,3 @@
-
 #' @import assertthat
 NULL
 
@@ -43,11 +42,13 @@ NULL
 #' # headers:
 #' restack_across(jams, 2)
 #' restack_across(jams, 2,
-#'       headers = FALSE)
+#'   headers = FALSE
+#' )
 #'
 #' # on_remainder:
 #' restack_across(jams, 3,
-#'       on_remainder = "fill")
+#'   on_remainder = "fill"
+#' )
 #'
 #' @name restack-across-down
 NULL
@@ -55,19 +56,17 @@ NULL
 
 #' @export
 #' @rdname restack-across-down
-restack_across <- function (
-        ht,
-        rows,
-        headers = TRUE,
-        on_remainder = c("warn", "stop", "fill")
-      ) {
+restack_across <- function(ht,
+                           rows,
+                           headers = TRUE,
+                           on_remainder = c("warn", "stop", "fill")) {
   assert_that(is_huxtable(ht), is.count(rows), is.flag(headers))
   on_remainder <- match.arg(on_remainder)
   on_remainder <- switch(on_remainder,
-          "warn" = warning,
-          "stop" = stop,
-          identity # i.e. do nothing
-        )
+    "warn" = warning,
+    "stop" = stop,
+    identity # i.e. do nothing
+  )
 
   ht_list <- split_across(ht, after = rows, headers = headers)
   new_ht <- ht_list[[1]]
@@ -79,8 +78,10 @@ restack_across <- function (
   if (length(ht_list) > 1) {
     on_remainder(sprintf("Table was not split equally into %s rows", rows))
     remainder <- ht_list[[2]]
-    remainder <- rbind(remainder,
-      matrix("", nrow(new_ht) - nrow(remainder), ncol(remainder)))
+    remainder <- rbind(
+      remainder,
+      matrix("", nrow(new_ht) - nrow(remainder), ncol(remainder))
+    )
     new_ht <- cbind(new_ht, remainder)
   }
 
@@ -90,19 +91,17 @@ restack_across <- function (
 
 #' @export
 #' @rdname restack-across-down
-restack_down <- function (
-        ht,
-        cols,
-        headers = TRUE,
-        on_remainder = c("warn", "stop", "fill")
-      ) {
+restack_down <- function(ht,
+                         cols,
+                         headers = TRUE,
+                         on_remainder = c("warn", "stop", "fill")) {
   assert_that(is_huxtable(ht), is.count(cols), is.flag(headers))
   on_remainder <- match.arg(on_remainder)
   on_remainder <- switch(on_remainder,
-          "warn" = warning,
-          "stop" = stop,
-          identity # i.e. do nothing
-        )
+    "warn" = warning,
+    "stop" = stop,
+    identity # i.e. do nothing
+  )
 
   ht_list <- split_down(ht, after = cols, headers = headers)
   new_ht <- ht_list[[1]]
@@ -114,8 +113,10 @@ restack_down <- function (
   if (length(ht_list) > 1) {
     on_remainder(sprintf("Table was not split equally into %s cols", cols))
     remainder <- ht_list[[2]]
-    remainder <- cbind(remainder,
-          matrix("", nrow(remainder), ncol(new_ht) - ncol(remainder)))
+    remainder <- cbind(
+      remainder,
+      matrix("", nrow(remainder), ncol(new_ht) - ncol(remainder))
+    )
     new_ht <- rbind(new_ht, remainder)
   }
 
@@ -168,18 +169,16 @@ NULL
 
 #' @export
 #' @rdname split-across-down
-split_across <- function (
-        ht,
-        after,
-        height,
-        headers = TRUE
-      ) {
+split_across <- function(ht,
+                         after,
+                         height,
+                         headers = TRUE) {
   assert_that(is_hux(ht), is.flag(headers))
   if (missing(after) + missing(height) != 1) {
     stop("Exactly one of `after` and `height` must be specified")
   }
 
-  if (! missing(height)) {
+  if (!missing(height)) {
     assert_that(is.number(height), height > 0)
     after <- calc_after_by_size(height, row_height(ht))
   } else {
@@ -191,7 +190,7 @@ split_across <- function (
 
   row_list <- get_pos_list(after, nrow(ht))
 
-  ht_list <- lapply(row_list, function (rows) ht[rows,])
+  ht_list <- lapply(row_list, function(rows) ht[rows, ])
   if (headers && any(headers <- header_rows(ht))) {
     # for each first row/col, copy ALL previous headers.
     for (i in seq_along(after)) {
@@ -210,18 +209,16 @@ split_across <- function (
 
 #' @export
 #' @rdname split-across-down
-split_down <- function (
-        ht,
-        after,
-        width,
-        headers = TRUE
-      ) {
+split_down <- function(ht,
+                       after,
+                       width,
+                       headers = TRUE) {
   assert_that(is_hux(ht), is.flag(headers))
   if (missing(after) + missing(width) != 1) {
     stop("Exactly one of `after` and `width` must be specified")
   }
 
-  if (! missing(width)) {
+  if (!missing(width)) {
     assert_that(is.number(width), width > 0)
     after <- calc_after_by_size(width, col_width(ht))
   } else {
@@ -233,7 +230,7 @@ split_down <- function (
 
   col_list <- get_pos_list(after, ncol(ht))
 
-  ht_list <- lapply(col_list, function (cols) ht[, cols])
+  ht_list <- lapply(col_list, function(cols) ht[, cols])
 
   if (headers && any(headers <- header_cols(ht))) {
     # for each first row/col, copy ALL previous headers.
@@ -251,32 +248,37 @@ split_down <- function (
 }
 
 
-check_after <- function (after, last_row_col) {
-  assert_that(noNA(after), length(after) > 0, all(after >= 0),
-    all(after <= last_row_col))
+check_after <- function(after, last_row_col) {
+  assert_that(
+    noNA(after), length(after) > 0, all(after >= 0),
+    all(after <= last_row_col)
+  )
 }
 
 
-calc_after_by_size <- function (size, lengths) {
-  assert_that(is.numeric(lengths), ! anyNA(lengths))
+calc_after_by_size <- function(size, lengths) {
+  assert_that(is.numeric(lengths), !anyNA(lengths))
   # find the biggest total length
   total_lengths <- cumsum(lengths)
   poss <- total_lengths <= size
-  if (! any(poss)) stop("Can't guarantee huxtables to all be less than ", size)
+  if (!any(poss)) stop("Can't guarantee huxtables to all be less than ", size)
   biggest_poss <- max(which(poss))
-  if (biggest_poss == length(lengths)) return(biggest_poss)
-  c(biggest_poss,
+  if (biggest_poss == length(lengths)) {
+    return(biggest_poss)
+  }
+  c(
+    biggest_poss,
     biggest_poss + calc_after_by_size(size, lengths[-seq(1L, biggest_poss)])
   )
 }
 
 
-get_pos_list <- function (after, endpoint) {
+get_pos_list <- function(after, endpoint) {
   after <- sort(after)
   after <- c(0, after)
   if (max(after) < endpoint) after <- c(after, endpoint)
-  pos_list <- lapply(seq_len(length(after) - 1), function (x) {
-    seq(after[x] + 1, after[x+1])
+  pos_list <- lapply(seq_len(length(after) - 1), function(x) {
+    seq(after[x] + 1, after[x + 1])
   })
 
   pos_list
