@@ -1,4 +1,3 @@
-
 #' Prices of 3 jams
 #'
 #' A huxtable of jams.
@@ -12,8 +11,10 @@
   set_default_option("huxtable.autoformat", TRUE)
   set_default_option("huxtable.autolabel", TRUE)
   set_default_option("huxtable.bookdown", NULL)
-  set_default_option("huxtable.color_screen",
-        requireNamespace("crayon", quietly = TRUE))
+  set_default_option(
+    "huxtable.color_screen",
+    requireNamespace("crayon", quietly = TRUE)
+  )
   set_default_option("huxtable.knit_print_df_theme", theme_plain)
   set_default_option("huxtable.print", print_screen)
   set_default_option("huxtable.latex_use_fontspec", FALSE)
@@ -21,18 +22,18 @@
   set_default_option("huxtable.long_minus", FALSE)
   set_default_option("huxtable.quarto_process", FALSE)
   set_default_option("huxtable.autoformat_number_format", list(
-          integer = 0,
-          numeric = "%.3g",
-          complex = "%.3g"
-        ))
+    integer = 0,
+    numeric = "%.3g",
+    complex = "%.3g"
+  ))
   set_default_option("huxtable.autoformat_align", list(
-          numeric = getOption("OutDec", "."),
-          complex = getOption("OutDec", "."),
-          integer = "right",
-          Date    = "right",
-          POSIXct = "right",
-          POSIXlt = "right"
-        ))
+    numeric = getOption("OutDec", "."),
+    complex = getOption("OutDec", "."),
+    integer = "right",
+    Date    = "right",
+    POSIXct = "right",
+    POSIXlt = "right"
+  ))
 
   if (requireNamespace("knitr", quietly = TRUE)) {
     register_s3_method("knitr", "knit_print")
@@ -53,12 +54,12 @@
 }
 
 
-.onAttach <- function (libname, pkgname) {
+.onAttach <- function(libname, pkgname) {
   set_default_option("huxtable.knit_print_df", TRUE)
 }
 
 
-set_default_option <- function (opt, value) {
+set_default_option <- function(opt, value) {
   ol <- list(getOption(opt, value))
   names(ol) <- opt
   options(ol)
